@@ -5,12 +5,14 @@ use rusty_v8 as v8;
 // so it can implement Deserialize by itself
 
 // Classifies v8::Values into sub-types
+#[derive(Debug)]
 pub enum ValueType {
   Null,
   Bool,
   Number,
   String,
   Array,
+  ArrayBufferView,
   Object,
 }
 
@@ -24,6 +26,8 @@ impl ValueType {
       return Self::String;
     } else if v.is_array() {
       return Self::Array;
+    } else if v.is_array_buffer_view() {
+      return Self::ArrayBufferView;
     } else if v.is_object() {
       return Self::Object;
     } else if v.is_null_or_undefined() {
